Index: include/dartino_relocation_api.h |
diff --git a/include/fletch_relocation_api.h b/include/dartino_relocation_api.h |
similarity index 74% |
rename from include/fletch_relocation_api.h |
rename to include/dartino_relocation_api.h |
index 4064e1c86721eb858ef0119f5cc51d288cd72f04..dafab0dabc302258340b0d75083602a884de4dce 100644 |
--- a/include/fletch_relocation_api.h |
+++ b/include/dartino_relocation_api.h |
@@ -2,19 +2,19 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-#ifndef INCLUDE_FLETCH_RELOCATION_API_H_ |
-#define INCLUDE_FLETCH_RELOCATION_API_H_ |
+#ifndef INCLUDE_DARTINO_RELOCATION_API_H_ |
+#define INCLUDE_DARTINO_RELOCATION_API_H_ |
#include <stdint.h> |
#include <stddef.h> |
-#include "include/fletch_api.h" |
+#include "include/dartino_api.h" |
// Returns the memory requirement in bytes for the given program. The |
// reported memory requirement includes the size of an info block as |
// appended when relocating a program. It is thus suitable as size |
-// argument to FletchRelocateProgram. |
-FLETCH_EXPORT size_t FletchGetProgramSize(FletchProgram program); |
+// argument to DartinoRelocateProgram. |
+DARTINO_EXPORT size_t DartinoGetProgramSize(DartinoProgram program); |
// Relocates the given program to the new address given by base. |
// The resulting blob is written to the memory region referred to |
@@ -26,14 +26,14 @@ FLETCH_EXPORT size_t FletchGetProgramSize(FletchProgram program); |
// |
// The memory region pointed to by target has to be big enough to |
// hold the relocated program plus an appended info block. The |
// function FletchGetProgramSize can be used to query this information. |
// |
// The address referred to by base has to be 4k aligned. |
// |
// On success, the number of bytes written is returned. Otherwise, |
// a negative value is returned. |
-FLETCH_EXPORT int FletchRelocateProgram(FletchProgram program, |
+DARTINO_EXPORT int DartinoRelocateProgram(DartinoProgram program, |
void* target, |
uintptr_t base); |
-#endif // INCLUDE_FLETCH_RELOCATION_API_H_ |
+#endif // INCLUDE_DARTINO_RELOCATION_API_H_ |
@@ -26,14 +26,14 @@ FLETCH_EXPORT size_t FletchGetProgramSize(FletchProgram program); |
// The memory region pointed to by target has to be big enough to |
// hold the relocated program plus an appended info block. The |
-// function FletchGetProgramSize can be used to query this information. |
+// function DartinoGetProgramSize can be used to query this information. |
// |
// The address referred to by base has to be 4k aligned. |